pilas.interprete_base

Package pilas :: Module interprete_base |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.interprete_base

     1  # -*- coding: utf-8 -*-
     2
     3  # Form implementation generated from reading ui file 'interprete.ui'
     4  #
     5  # Created: Tue Aug 28 17:43:39 2012
     6  #      by: PyQt4 UI code generator 4.9.1
     7  #
     8  # WARNING! All changes made in this file will be lost!
     9
    10  from PyQt4 import QtCore, QtGui
    11
    12  try:
    13      _fromUtf8 = QtCore.QString.fromUtf8
    14  except AttributeError:
    15      _fromUtf8 = lambda s: s
    16
    17 -class Ui_InterpreteDialog(object):
    18 -    def setupUi(self, InterpreteDialog):
    19          InterpreteDialog.setObjectName(_fromUtf8("InterpreteDialog"))
    20          InterpreteDialog.resize(642, 554)
    21          self.gridLayout = QtGui.QGridLayout(InterpreteDialog)
    22          self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
    23          self.splitter = QtGui.QSplitter(InterpreteDialog)
    24          self.splitter.setOrientation(QtCore.Qt.Vertical)
    25          self.splitter.setObjectName(_fromUtf8("splitter"))
    26          self.canvas = QtGui.QStackedWidget(self.splitter)
    27          self.canvas.setMinimumSize(QtCore.QSize(320, 240))
    28          self.canvas.setObjectName(_fromUtf8("canvas"))
    29          self.page = QtGui.QWidget()
    30          self.page.setObjectName(_fromUtf8("page"))
    31          self.canvas.addWidget(self.page)
    32          self.page_2 = QtGui.QWidget()
    33          self.page_2.setObjectName(_fromUtf8("page_2"))
    34          self.canvas.addWidget(self.page_2)
    35          self.console = QtGui.QStackedWidget(self.splitter)
    36          self.console.setObjectName(_fromUtf8("console"))
    37          self.page_3 = QtGui.QWidget()
    38          self.page_3.setObjectName(_fromUtf8("page_3"))
    39          self.console.addWidget(self.page_3)
    40          self.page_4 = QtGui.QWidget()
    41          self.page_4.setObjectName(_fromUtf8("page_4"))
    42          self.console.addWidget(self.page_4)
    43          self.gridLayout.addWidget(self.splitter, 0, 0, 1, 1)
    44
    45          self.retranslateUi(InterpreteDialog)
    46          QtCore.QMetaObject.connectSlotsByName(InterpreteDialog)
    47
    48 -    def retranslateUi(self, InterpreteDialog):
    49          InterpreteDialog.setWindowTitle(QtGui.QApplication.translate("InterpreteDialog", "pilas-engine interprete", None, QtGui.QApplication.UnicodeUTF8))
    50
    51
    52  if __name__ == "__main__":
    53      import sys
    54      app = QtGui.QApplication(sys.argv)
    55      InterpreteDialog = QtGui.QDialog()
    56      ui = Ui_InterpreteDialog()
    57      ui.setupUi(InterpreteDialog)
    58      InterpreteDialog.show()
    59      sys.exit(app.exec_())
    60